summaryrefslogtreecommitdiffstats
path: root/kioslaves/mbox/readmbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kioslaves/mbox/readmbox.h')
-rw-r--r--kioslaves/mbox/readmbox.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kioslaves/mbox/readmbox.h b/kioslaves/mbox/readmbox.h
index ea63068c..046767be 100644
--- a/kioslaves/mbox/readmbox.h
+++ b/kioslaves/mbox/readmbox.h
@@ -40,11 +40,11 @@ public:
* Constructor
*
* @param info The information of the file to read
* @param tqparent The instance of the tqparent MBoxProtocol.
* @param onlynew Only read new messages from the MBox file.
* @param savetime If true, the atime of the mbox-file is preserved (note that this touch the ctime).
*/
- ReadMBox( const UrlInfo* info, MBoxProtocol* tqparent, bool onlynew = false, bool savetime = false );
+ ReadMBox( const UrlInfo* info, MBoxProtocol* parent, bool onlynew = false, bool savetime = false );
/**
* Destructor
@@ -40,11 +40,11 @@ public:
*
* @param info The information of the file to read
- * @param tqparent The instance of the tqparent MBoxProtocol.
+ * @param parent The instance of the parent MBoxProtocol.
* @param onlynew Only read new messages from the MBox file.
* @param savetime If true, the atime of the mbox-file is preserved (note that this touch the ctime).